@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -49,6 +51,13 @@ class AutomationAgentInfo(AbstractModel):
         self.LastHeartbeatTime = params.get("LastHeartbeatTime")
         self.AgentStatus = params.get("AgentStatus")
         self.Environment = params.get("Environment")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class Command(AbstractModel):
@@ -84,6 +93,8 @@ class Command(AbstractModel):
         :type FormattedDescription: str
         :param CreatedBy: 命令创建者。TAT 代表公共命令，USER 代表个人命令。
         :type CreatedBy: str
+        :param Tags: 命令关联的标签列表。
+        :type Tags: list of Tag
         """
         self.CommandId = None
         self.CommandName = None
@@ -98,6 +109,7 @@ class Command(AbstractModel):
         self.DefaultParameters = None
         self.FormattedDescription = None
         self.CreatedBy = None
+        self.Tags = None
 
 
     def _deserialize(self, params):
@@ -114,6 +126,19 @@ class Command(AbstractModel):
         self.DefaultParameters = params.get("DefaultParameters")
         self.FormattedDescription = params.get("FormattedDescription")
         self.CreatedBy = params.get("CreatedBy")
+        if params.get("Tags") is not None:
+            self.Tags = []
+            for item in params.get("Tags"):
+                obj = Tag()
+                obj._deserialize(item)
+                self.Tags.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CommandDocument(AbstractModel):
@@ -143,6 +168,13 @@ class CommandDocument(AbstractModel):
         self.CommandType = params.get("CommandType")
         self.Timeout = params.get("Timeout")
         self.WorkingDirectory = params.get("WorkingDirectory")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateCommandRequest(AbstractModel):
@@ -174,6 +206,8 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
 自定义参数最多20个。
 自定义参数名称需符合以下规范：字符数目上限64，可选范围【a-zA-Z0-9-_】。
         :type DefaultParameters: str
+        :param Tags: 为命令关联的标签，列表长度不超过10。
+        :type Tags: list of Tag
         """
         self.CommandName = None
         self.Content = None
@@ -183,6 +217,7 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
         self.Timeout = None
         self.EnableParameter = None
         self.DefaultParameters = None
+        self.Tags = None
 
 
     def _deserialize(self, params):
@@ -194,6 +229,19 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
         self.Timeout = params.get("Timeout")
         self.EnableParameter = params.get("EnableParameter")
         self.DefaultParameters = params.get("DefaultParameters")
+        if params.get("Tags") is not None:
+            self.Tags = []
+            for item in params.get("Tags"):
+                obj = Tag()
+                obj._deserialize(item)
+                self.Tags.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateCommandResponse(AbstractModel):
@@ -215,6 +263,13 @@ class CreateCommandResponse(AbstractModel):
     def _deserialize(self, params):
         self.CommandId = params.get("CommandId")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteCommandRequest(AbstractModel):
@@ -232,6 +287,13 @@ class DeleteCommandRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.CommandId = params.get("CommandId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteCommandResponse(AbstractModel):
@@ -249,6 +311,13 @@ class DeleteCommandResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAutomationAgentStatusRequest(AbstractModel):
@@ -283,6 +352,13 @@ class DescribeAutomationAgentStatusRequest(AbstractModel):
                 self.Filters.append(obj)
         self.Limit = params.get("Limit")
         self.Offset = params.get("Offset")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAutomationAgentStatusResponse(AbstractModel):
@@ -313,6 +389,13 @@ class DescribeAutomationAgentStatusResponse(AbstractModel):
                 self.AutomationAgentSet.append(obj)
         self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeCommandsRequest(AbstractModel):
@@ -324,7 +407,15 @@ class DescribeCommandsRequest(AbstractModel):
         """
         :param CommandIds: 命令ID列表，每次请求的上限为100。参数不支持同时指定 `CommandIds` 和 `Filters` 。
         :type CommandIds: list of str
-        :param Filters: 过滤条件。<br> <li> command-id - String - 是否必填：否 -（过滤条件）按照命令ID过滤。<br> <li> command-name - String - 是否必填：否 -（过滤条件）按照命令名称过滤。<br> <li> created-by - String - 是否必填：否 -（过滤条件）按照命令创建者过滤，取值为 TAT 或 USER，TAT 代表公共命令，USER 代表由用户创建的命令。 <br>每次请求的 `Filters` 的上限为10， `Filter.Values` 的上限为5。参数不支持同时指定 `CommandIds` 和 `Filters` 。
+        :param Filters: 过滤条件。
+<li> command-id - String - 是否必填：否 -（过滤条件）按照命令ID过滤。
+<li> command-name - String - 是否必填：否 -（过滤条件）按照命令名称过滤。
+<li> created-by - String - 是否必填：否 -（过滤条件）按照命令创建者过滤，取值为 TAT 或 USER，TAT 代表公共命令，USER 代表由用户创建的命令。 
+<li> tag-key - String - 是否必填：否 -（过滤条件）按照标签键进行过滤。</li>
+<li> tag-value - String - 是否必填：否 -（过滤条件）按照标签值进行过滤。</li>
+<li> tag:tag-key - String - 是否必填：否 -（过滤条件）按照标签键值对进行过滤。 tag-key使用具体的标签键进行替换。使用请参考示例4</li>
+
+每次请求的 `Filters` 的上限为10， `Filter.Values` 的上限为5。参数不支持同时指定 `CommandIds` 和 `Filters` 。
         :type Filters: list of Filter
         :param Limit: 返回数量，默认为20，最大值为100。关于 `Limit` 的更进一步介绍请参考 API [简介](https://cloud.tencent.com/document/api/213/15688)中的相关小节。
         :type Limit: int
@@ -347,6 +438,13 @@ class DescribeCommandsRequest(AbstractModel):
                 self.Filters.append(obj)
         self.Limit = params.get("Limit")
         self.Offset = params.get("Offset")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeCommandsResponse(AbstractModel):
@@ -377,6 +475,13 @@ class DescribeCommandsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.CommandSet.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeInvocationTasksRequest(AbstractModel):
@@ -415,6 +520,13 @@ class DescribeInvocationTasksRequest(AbstractModel):
         self.Limit = params.get("Limit")
         self.Offset = params.get("Offset")
         self.HideOutput = params.get("HideOutput")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeInvocationTasksResponse(AbstractModel):
@@ -445,6 +557,13 @@ class DescribeInvocationTasksResponse(AbstractModel):
                 obj._deserialize(item)
                 self.InvocationTaskSet.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeInvocationsRequest(AbstractModel):
@@ -479,6 +598,13 @@ class DescribeInvocationsRequest(AbstractModel):
                 self.Filters.append(obj)
         self.Limit = params.get("Limit")
         self.Offset = params.get("Offset")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeInvocationsResponse(AbstractModel):
@@ -509,6 +635,13 @@ class DescribeInvocationsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.InvocationSet.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeRegionsRequest(AbstractModel):
@@ -545,6 +678,13 @@ class DescribeRegionsResponse(AbstractModel):
                 obj._deserialize(item)
                 self.RegionSet.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class Filter(AbstractModel):
@@ -577,6 +717,13 @@ class Filter(AbstractModel):
     def _deserialize(self, params):
         self.Name = params.get("Name")
         self.Values = params.get("Values")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class Invocation(AbstractModel):
@@ -645,6 +792,13 @@ class Invocation(AbstractModel):
         self.UpdatedTime = params.get("UpdatedTime")
         self.Parameters = params.get("Parameters")
         self.DefaultParameters = params.get("DefaultParameters")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class InvocationTask(AbstractModel):
@@ -715,6 +869,13 @@ class InvocationTask(AbstractModel):
         if params.get("CommandDocument") is not None:
             self.CommandDocument = CommandDocument()
             self.CommandDocument._deserialize(params.get("CommandDocument"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class InvocationTaskBasicInfo(AbstractModel):
@@ -749,6 +910,13 @@ class InvocationTaskBasicInfo(AbstractModel):
         self.InvocationTaskId = params.get("InvocationTaskId")
         self.TaskStatus = params.get("TaskStatus")
         self.InstanceId = params.get("InstanceId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class InvokeCommandRequest(AbstractModel):
@@ -778,6 +946,13 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
         self.CommandId = params.get("CommandId")
         self.InstanceIds = params.get("InstanceIds")
         self.Parameters = params.get("Parameters")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class InvokeCommandResponse(AbstractModel):
@@ -799,6 +974,13 @@ class InvokeCommandResponse(AbstractModel):
     def _deserialize(self, params):
         self.InvocationId = params.get("InvocationId")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyCommandRequest(AbstractModel):
@@ -849,6 +1031,13 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
         self.WorkingDirectory = params.get("WorkingDirectory")
         self.Timeout = params.get("Timeout")
         self.DefaultParameters = params.get("DefaultParameters")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyCommandResponse(AbstractModel):
@@ -866,6 +1055,13 @@ class ModifyCommandResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class PreviewReplacedCommandContentRequest(AbstractModel):
@@ -897,6 +1093,13 @@ CommandId 与 Content，必须且只能提供一个。
         self.Parameters = params.get("Parameters")
         self.CommandId = params.get("CommandId")
         self.Content = params.get("Content")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class PreviewReplacedCommandContentResponse(AbstractModel):
@@ -918,6 +1121,13 @@ class PreviewReplacedCommandContentResponse(AbstractModel):
     def _deserialize(self, params):
         self.ReplacedContent = params.get("ReplacedContent")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class RegionInfo(AbstractModel):
@@ -943,6 +1153,13 @@ class RegionInfo(AbstractModel):
         self.Region = params.get("Region")
         self.RegionName = params.get("RegionName")
         self.RegionState = params.get("RegionState")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class RunCommandRequest(AbstractModel):
@@ -989,6 +1206,8 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
 自定义参数最多20个。
 自定义参数名称需符合以下规范：字符数目上限64，可选范围【a-zA-Z0-9-_】。
         :type Parameters: str
+        :param Tags: 如果保存命令，可为命令设置标签。列表长度不超过10。
+        :type Tags: list of Tag
         """
         self.Content = None
         self.InstanceIds = None
@@ -1001,6 +1220,7 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
         self.EnableParameter = None
         self.DefaultParameters = None
         self.Parameters = None
+        self.Tags = None
 
 
     def _deserialize(self, params):
@@ -1015,6 +1235,19 @@ key为自定义参数名称，value为该参数的默认取值。kv均为字符
         self.EnableParameter = params.get("EnableParameter")
         self.DefaultParameters = params.get("DefaultParameters")
         self.Parameters = params.get("Parameters")
+        if params.get("Tags") is not None:
+            self.Tags = []
+            for item in params.get("Tags"):
+                obj = Tag()
+                obj._deserialize(item)
+                self.Tags.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class RunCommandResponse(AbstractModel):
@@ -1040,6 +1273,41 @@ class RunCommandResponse(AbstractModel):
         self.CommandId = params.get("CommandId")
         self.InvocationId = params.get("InvocationId")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
+
+
+class Tag(AbstractModel):
+    """标签
+
+    """
+
+    def __init__(self):
+        """
+        :param Key: 标签键。
+        :type Key: str
+        :param Value: 标签值。
+        :type Value: str
+        """
+        self.Key = None
+        self.Value = None
+
+
+    def _deserialize(self, params):
+        self.Key = params.get("Key")
+        self.Value = params.get("Value")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class TaskResult(AbstractModel):
@@ -1072,4 +1340,11 @@ class TaskResult(AbstractModel):
         self.Output = params.get("Output")
         self.ExecStartTime = params.get("ExecStartTime")
         self.ExecEndTime = params.get("ExecEndTime")
-        self.Dropped = params.get("Dropped")
\ No newline at end of file
+        self.Dropped = params.get("Dropped")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
\ No newline at end of file
